const NODE_ENV = process.env.NODE_ENV;
require('dotenv').config({ path: `./.env_${NODE_ENV}` });
let envs = process.env;
let value;

const calculateValue = () => {
    value = {
        port: envs.PORT || 8080,
        listenInaddrAny: envs.LISTEN_INADDR_ANY || 1, // allow public connect 0/1
        sentry: {
            dsn: envs.SENTRY,
            routeTimeout: parseInt(envs.SENTRY_ROUTE_TIMEOUT) || 30000,
        },
        cache: {
            type: envs.CACHE_TYPE || 'memory',
        },
        jwt: {
            secret: "aBDazk0U8X7/H1zX",
            header: "authorization",
            expires: "1H",
            expires_refresh: 7 * 24 * 60 * 60
        },
        mysql: {
            force: envs.MYSQL_FORCE,
            dialect: envs.MYSQL_DIALECT || 'mysql',
            host: envs.MYSQL_HOST || 'localhost',
            port: parseInt(envs.MYSQL_PORT) || 3306,
            username: envs.MYSQL_USERNAME || 'root',
            password: envs.MYSQL_PASSWORD || '123456',
            database: envs.MYSQL_DATABASE || '{{project_name}}',
        },
        redis: {
            port: parseInt(envs.REDIS_PORT) || 6379,
            host: envs.REDIS_HOST || 'localhost',
            password: envs.REDIS_PASSWORD || '',
            db: parseInt(envs.REDIS_DB) || 0,
        },
        email: {
            host: envs.EMAIL_HOST,
            port: parseInt(envs.EMAIL_PORT),
            secureConnection: true,
            auth: {
                user: envs.EMAIL_AUTH_USER,
                pass: envs.EMAIL_AUTH_PASS,
            }
        },
        ratelimit: {
            max: parseInt(envs.RATE_LIMIT_MAX) || 1000,
            duration: parseInt(envs.RATE_LIMIT_DURATION) || 30 * 60 * 1000
        },
        file: {
            max_form_limit: "10m",
            max_file_limit: 100 * 1024 * 1024,
            upload_dir: envs.FILE_UPLOAD_DIR || `upload`,
            expire_time: parseInt(envs.FILE_EXPIRE_TIME) || 24 * 60 * 60 * 1000,
        },
        loggerLevel: envs.LOGGER_LEVEL ? envs.LOGGER_LEVEL : envs.NODE_ENV === 'prod' ? 'info' : 'debug',
        allowOrigin: envs.ALLOW_ORIGIN || '*',
        blacklist: envs.BLACKLIST && envs.BLACKLIST.split(','),
        whitelist: envs.WHITELIST && envs.WHITELIST.split(','),
        allowLocalhost: envs.ALLOW_LOCALHOST,
        router_print: Boolean(envs.ROUTER_PRINT) || true
    };
};

calculateValue();

module.exports = {
    set: (env) => {
        envs = Object.assign(process.env, env);
        calculateValue();
    },
    get value() {
        return value;
    },
};
