const { Sequelize } = require('sequelize');
const logger = require('@/utils/logger');
const config = require('@/config').value;

const sequelize = new Sequelize(
    config.mysql.database,
    config.mysql.username,
    config.mysql.password, {
    host: config.mysql.host,
    port: config.mysql.port,
    dialect: 'mysql',
    logging: null,
    define: {
        charset: 'utf8mb4',
        dialectOptions: {
            collate: 'utf8mb4_general_ci'
        }
    }
});

const AdminUser = require("./models/AdminUser")(sequelize);
const AdminRole = require("./models/AdminRole")(sequelize);

const FileResources = require("./models/FileResources")(sequelize);

// 此处设置关联关系
AdminUser.belongsToMany(AdminRole, { through: `admin_user_role` });
AdminRole.belongsToMany(AdminUser, { through: 'admin_user_role' });

async function main() {
    const force = true;
    await sequelize.sync({ force });

    if (force) {
        const admin_users = await AdminUser.bulkCreate([{
            username: 'admin',
            age: 18,
            sex: 1
        }, {
            username: 'root',
            age: 18,
            sex: 1
        }]);

        const admin_roles = await AdminRole.bulkCreate([{
            role_name: 'admin'
        }, {
            role_name: 'user'
        }]);

        admin_users.forEach((user) => {
            admin_roles.forEach(async (role) => {
                await user.addAdminRole(role);
            });
        });
    }
}

(async () => {
    if (['dev'].indexOf(process.env.NODE_ENV) > -1 && process.env.DB_INIT === 'true') {
        await sequelize.sync({ force: true });
        await main();
    }

    logger.info('database init success...');
})();

module.exports = {
    Sequelize,
    AdminUser,
    AdminRole,
    FileResources,
    sequelize
};