const { RequestProgressError } = require('@/errors');

const statusCodes = {
    CONTINUE: 100,
    OK: 200,
    CREATED: 201,
    ACCEPTED: 202,
    NO_CONTENT: 204,
    BAD_REQUEST: 400,
    UNAUTHORIZED: 401,
    FORBIDDEN: 403,
    NOT_FOUND: 404,
    REQUEST_TIMEOUT: 408,
    UNPROCESSABLE_ENTITY: 422,
    INTERNAL_SERVER_ERROR: 500,
    NOT_IMPLEMENTED: 501,
    BAD_GATEWAY: 502,
    SERVICE_UNAVAILABLE: 503,
    GATEWAY_TIME_OUT: 504,
};

function responseHandler() {
    return async (ctx, next) => {
        ctx.res.statusCodes = statusCodes;
        ctx.statusCodes = ctx.res.statusCodes;

        ctx.res.success = ({ statusCode, data = null, message = null || 'success' }) => {
            const status = 0;
            ctx.status = statusCode;
            ctx.body = { status, data, message };
        };

        ctx.res.ok = (params = {}) => {
            ctx.res.success({
                ...params,
                statusCode: statusCodes.OK,
            });
        };

        ctx.res.fail = ({ statusCode, code = -1, data = null, message = null }) => {
            const status = -1;
            if (!!statusCode && (statusCode >= 400 && statusCode < 500)) {
                ctx.status = statusCode;

            } else if (!(ctx.status >= 400 && ctx.status < 500)) {
                ctx.status = statusCodes.BAD_REQUEST;
            }

            ctx.body = { status, code, data, message };
            throw new RequestProgressError();
        };

        ctx.res.noContent = (params = {}) => {
            ctx.res.success({
                ...params,
                statusCode: statusCodes.NO_CONTENT,
            });
        };

        ctx.res.noAuth = (params = {}) => {
            ctx.res.fail({
                ...params,
                statusCode: statusCodes.UNAUTHORIZED,
            });
        };

        ctx.res.badRequest = (params = {}) => {
            ctx.res.fail({
                ...params,
                statusCode: statusCodes.BAD_REQUEST,
            });
        };

        ctx.res.badParamsRequest = (params = {}) => {
            ctx.res.fail({
                ...params,
                message: 'params error'
            });
        };

        await next();
    };
}

module.exports = responseHandler;
