const config = require('@/config').value;
// const jsonwebtoken = require('jsonwebtoken');
const { verify, decode, sign } = require('@/utils/jwt');

const exclude_url = [/^\/ping/];

module.exports = async (ctx, next) => {
    const req_url = ctx.url;
    if (exclude_url.some((url) => req_url.match(url))) {
        await next();

    } else {
        const token = ctx.headers[config.jwt.header];
        if (!token) {
            ctx.res.noAuth({ code: 401, message: "auth fail" });
        }

        try {
            const payload = verify(token, config.jwt.secret);
            if (payload) {
                ctx.user = payload;
                await next();
            }

        } catch (err) {
            const exp = parseInt(new Date(err.expiredAt).getTime() / 1000);
            if ((new Date().getTime() / 1000 - exp) < config.jwt.expires_refresh) {
                const payload = decode(token);
                ctx.user = payload;
                delete payload.exp;
                ctx.res.setHeader(config.jwt.header, sign(payload, config.jwt.expires));
                await next();
            } else {
                ctx.res.noAuth({ code: 401, message: "auth expire" });
            }
        }
    }

};