const Redis = require('ioredis');
const logger = require('@/utils/logger');
const config = require('@/config').value;

const redis = new Redis({
    port: config.redis.port,
    host: config.redis.host,
    password: config.redis.password,
    db: config.redis.db,
});

const status = { available: false };

redis.on('error', (error) => {
    status.available = false;
    logger.error('Redis error: ', error);
});

redis.on('end', () => {
    status.available = false;
});

redis.on('connect', () => {
    status.available = true;
    logger.info('Redis connected.');
});

module.exports = {
    getValue: async (key) => {
        if (key && status.available) {
            const value = await redis.get(key);
            return value;
        }
    },
    setValue: async (key, value, expire) => {
        if (key && status.available) {
            await redis.set(key, value, 'EX', expire);
        }
    },
    delValue: async (key) => {
        if (key && status.available) {
            await redis.del(key);
        }
    },
    clients: { redis },
    status,
};